@@ -98,3 +98,22 @@ def test_lz4frame_open_write_read(
         data_out = fp.read()
 
     assert data_out == data
+
+
+def test_lz4frame_flush():
+    data_1 = b"This is a..."
+    data_2 = b" test string!"
+
+    with lz4frame.open("testfile", mode="w") as fp_write:
+        fp_write.write(data_1)
+        fp_write.flush()
+
+        fp_write.write(data_2)
+
+        with lz4frame.open("testfile", mode="r") as fp_read:
+            assert fp_read.read() == data_1
+
+        fp_write.flush()
+
+        with lz4frame.open("testfile", mode="r") as fp_read:
+            assert fp_read.read() == data_1 + data_2
